@@ -1,6 +1,6 @@
 package Git::Hooks;
 {
-  $Git::Hooks::VERSION = '0.048';
+  $Git::Hooks::VERSION = '0.049';
 }
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
 
@@ -25,7 +25,7 @@ BEGIN {                ## no critic (Subroutines::RequireArgUnpacking)
             PRE_PUSH PRE_RECEIVE UPDATE POST_RECEIVE POST_UPDATE
             PRE_AUTO_GC POST_REWRITE
 
-            REF_UPDATE PATCHSET_CREATED
+            REF_UPDATE PATCHSET_CREATED DRAFT_PUBLISHED
           /;
 
     for my $installer (@installers) {
@@ -126,12 +126,12 @@ sub spawn_external_hook {
         if ($exit == 0) {
             return 1;
         } elsif ($exit == -1) {
-            $git->error(__PACKAGE__, ": failed to execute '$file': $!\n");
+            $git->error(__PACKAGE__, ": failed to execute '$file'", $!);
         } elsif ($exit & 127) {
-            $git->error(__PACKAGE__, sprintf("'$file' died with signal %d, %s coredump\n",
+            $git->error(__PACKAGE__, sprintf("'$file' died with signal %d, %s coredump",
                                              ($exit & 127), ($exit & 128) ? 'with' : 'without'));
         } else {
-            $git->error(__PACKAGE__, sprintf("'$file' exited abnormally with value %d\n", $exit >> 8));
+            $git->error(__PACKAGE__, sprintf("'$file' exited abnormally with value %d", $exit >> 8));
         }
 
         return 0;
@@ -295,7 +295,7 @@ sub _prepare_update {
 # list into a hash and change the original argument list into a single
 # hash-ref. We also record information about the user performing the
 # push. Based on:
-# http://gerrit-documentation.googlecode.com/svn/Documentation/2.6/config-hooks.html
+# https://gerrit-review.googlesource.com/Documentation/config-hooks.html
 
 sub _prepare_gerrit_args {
     my ($git, $args) = @_;
@@ -344,49 +344,7 @@ sub _prepare_gerrit_args {
     };
 
     @$args = (\%opt);
-    return;
-}
 
-# Gerrit's patchset-created hook is invoked when a commit is pushed to
-# a refs/for/* branch for revision. It's invoked asynchronously, i.e.,
-# it can't stop the push to happen. Instead, if it detects any
-# problem, we must reject the commit via Gerrit's own revision
-# process. So, we prepare a post hook action in which we see if there
-# were errors that should be signalled via as code review action.
-
-sub _prepare_gerrit_patchset_created {
-    my ($git, $args) = @_;
-
-    _prepare_gerrit_args($git, $args);
-    post_hook(
-        sub {
-            my ($hook_name, $git, $args) = @_; ## no critic (Variables::ProhibitReusedNames)
-
-            my $resource = do {
-                my $change   = $args->{'--change'}
-                    or die __PACKAGE__, ": Missing --change argument to Gerrit's patchset_created hook.\n";
-                my $patchset = $args->{'--patchset'}
-                    or die __PACKAGE__, ": Missing --patchset argument to Gerrit's patchset_created hook.\n";
-
-                "/changes/$change/revisions/$patchset/review";
-            };
-
-            my $review_label = $git->get_config('githooks.gerrit' => 'review_label') || 'Code-Review';
-
-            if (my @errors = $git->get_errors()) {
-                $args->{gerrit}->POST($resource, {
-                    labels  => {$review_label => $git->get_config('githooks.gerrit' => 'vote_nok') || -1},
-                    message => join("\n\n", @errors),
-                });
-            } else {
-                $args->{gerrit}->POST($resource, {
-                    labels  => {$review_label => $git->get_config('githooks.gerrit' => 'vote_ok')  || +1},
-                });
-            }
-
-            return;
-        }
-    );
     return;
 }
 
@@ -407,6 +365,83 @@ sub _prepare_gerrit_ref_update {
     return;
 }
 
+# The following routine is the post_hook used by the Gerrit hooks
+# patchset-created and draft-published. It basically casts a vote on the
+# patchset based on the errors found during the hook processing.
+
+sub _gerrit_patchset_post_hook {
+    my ($hook_name, $git, $args) = @_;
+
+    my $resource = do {
+        my $change   = $args->{'--change'}
+            or die __PACKAGE__, ": Missing --change argument to Gerrit's $hook_name hook.\n";
+        my $patchset = $args->{'--patchset'}
+            or die __PACKAGE__, ": Missing --patchset argument to Gerrit's $hook_name hook.\n";
+
+        "/changes/$change/revisions/$patchset/review";
+    };
+
+    my $review_label = $git->get_config('githooks.gerrit' => 'review-label') || 'Code-Review';
+
+    my %params;
+
+    if (my @errors = $git->get_errors()) {
+        $params{labels}  = { $review_label => $git->get_config('githooks.gerrit' => 'vote-nok') || -1 };
+        $params{message} = join("\n\n", @errors);
+    } else {
+        $params{labels}  = { $review_label => $git->get_config('githooks.gerrit' => 'vote-ok')  || +1 };
+        if (my $comment = $git->get_config('githooks.gerrit' => 'comment-ok')) {
+            $params{message} = "[Git::Hooks] $comment";
+        }
+    }
+
+    my $eval = eval { $args->{gerrit}->POST($resource, \%params) };
+    unless ($eval) {
+        my $error = $@;
+        require Data::Dumper;
+        die __PACKAGE__ . ": error in Gerrit::REST::POST(\n" . Data::Dumper::Dumper($resource, \%params) . ")\n: $error\n";
+    }
+
+    return;
+}
+
+# Gerrit's patchset-created hook is invoked when a commit is pushed to a
+# refs/for/* branch for revision. It's invoked asynchronously, i.e., it
+# can't stop the push to happen. Instead, if it detects any problem, we must
+# reject the commit via Gerrit's own revision process. So, we prepare a post
+# hook action in which we see if there were errors that should be signaled
+# via a code review action. Note, however, that draft changes can only be
+# accessed by their respective owners and usually can't be voted on by the
+# hook. So, draft changes aren't voted on and we exit the hook prematurely.
+# The arguments for the hook are these:
+
+# patchset-created --change <change id> --is-draft <boolean> \
+# --kind <change kind> --change-url <change url> \
+# --change-owner <change owner> --project <project name> \
+# --branch <branch> --topic <topic> --uploader <uploader>
+# --commit <sha1> --patchset <patchset id>
+
+# Gerrit's draft-published hook is invoked when a draft change is
+# published. In this state they're are visible by the hook and can be voted
+# on. The arguments for the hook are these:
+
+# draft-published --change <change id> --change-url <change url> \
+# --change-owner <change owner> --project <project name> \
+# --branch <branch> --topic <topic> --uploader <uploader> \
+# --commit <sha1> --patchset <patchset id>
+
+sub _prepare_gerrit_patchset {
+    my ($git, $args) = @_;
+
+    _prepare_gerrit_args($git, $args);
+
+    exit(0) if exists $args->[0]{'--is-draft'} and $args->[0]{'--is-draft'} eq 'true';
+
+    post_hook(\&_gerrit_patchset_post_hook);
+
+    return;
+}
+
 # The %prepare_hook hash maps hook names to the routine that must be
 # invoked in order to "prepare" their arguments.
 
@@ -417,7 +452,8 @@ my %prepare_hook = (
     'pre-receive'      => \&_prepare_receive,
     'post-receive'     => \&_prepare_receive,
     'ref-update'       => \&_prepare_gerrit_ref_update,
-    'patchset-created' => \&_prepare_gerrit_patchset_created,
+    'patchset-created' => \&_prepare_gerrit_patchset,
+    'draft-published'  => \&_prepare_gerrit_patchset,
 );
 
 ################
@@ -454,11 +490,7 @@ sub _load_plugins {
         my $exit = do {
             if ($prefix) {
                 # It must be a module name
-
-                ## no critic (ErrorHandling::RequireCheckingReturnValueOfEval, Modules::RequireBarewordIncludes)
-                eval "require $prefix$plugin";
-                ## use critic
-
+                eval "require $prefix$plugin"; ## no critic (ProhibitStringyEval, RequireCheckingReturnValueOfEval)
             } else {
                 # Otherwise, it's a basename that we must look for
                 # in @plugin_dirs
@@ -484,13 +516,16 @@ sub _load_plugins {
 # name and arguments, sets up the environment, loads plugins and
 # invokes the appropriate hook functions.
 
-sub run_hook {
+sub run_hook {                  ## no critic (Subroutines::ProhibitExcessComplexity)
     my ($hook_name, @args) = @_;
 
     $hook_name = basename $hook_name;
 
     my $git = Git::More->repository();
 
+    # Don't show context in error messages if requested
+    $git->nocarp if $git->get_config(githooks => 'nocarp');
+
     # Some hooks need some argument munging before we invoke them
     if (my $prepare = $prepare_hook{$hook_name}) {
         $prepare->($git, \@args);
@@ -506,7 +541,7 @@ sub run_hook {
             # If they fail they invoke Git::More::error.
         } elsif (length $@) {
             # Old hooks die when they fail...
-            $git->error(__PACKAGE__ . "($hook_name)", $@);
+            $git->error(__PACKAGE__ . "($hook_name)", "Hook failed", $@);
         } else {
             # ...and return undef when they succeed.
         }
@@ -519,11 +554,11 @@ sub run_hook {
                 ($git->get_config(githooks => 'hooks'), catfile($git->repo_path(), 'hooks.d'))
         ) {
             opendir my $dh, $dir
-                or $git->error(__PACKAGE__, ": cannot opendir $dir: $!\n")
+                or $git->error(__PACKAGE__, ": cannot opendir '$dir'", $!)
                     and next;
             foreach my $file (grep {-f && -x} map {catfile($dir, $_)} readdir $dh) {
                 spawn_external_hook($git, $file, $hook_name, @args)
-                    or $git->error(__PACKAGE__, ": error in external hook '$file'\n");
+                    or $git->error(__PACKAGE__, ": error in external hook '$file'");
             }
         }
     }
@@ -566,7 +601,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 SYNOPSIS
 
@@ -759,7 +794,7 @@ For example:
             my ($mode, $sha, $n, $name) = split / /;
             my $size = $git->command('cat-file' => '-s', $sha);
             $size <= $LIMIT
-                or $git->error('CheckSize', "File '$name' has $size bytes, more than our limit of $LIMIT.\n"
+                or $git->error('CheckSize', "File '$name' has $size bytes, more than our limit of $LIMIT"
                     and $errors++;
         }
 
@@ -902,10 +937,10 @@ management for Git based projects. It's based on
 L<JGit|http://www.eclipse.org/jgit/>, which is a pure Java
 implementation of Git.
 
-Up to version 2.6.0, Gerrit still doesn't support Git standard
-hooks. However, it implements its own L<special
-hooks|http://gerrit-documentation.googlecode.com/svn/Documentation/2.6/config-hooks.html>.
-B<Git::Hooks> currently supports only two of Gerrit hooks:
+Gerrit doesn't support Git standard hooks. However, it implements its own
+L<special
+hooks|https://gerrit-review.googlesource.com/Documentation/config-hooks.html>.
+B<Git::Hooks> currently supports only three of Gerrit hooks:
 
 =head3 ref-update
 
@@ -915,7 +950,7 @@ and Git::Hooks's plugins usually support them both together.
 
 =head3 patchset-created
 
-The B<patchset-created> hook is executed asynchrounously when a user
+The B<patchset-created> hook is executed asynchronously when a user
 performs a push to one of Gerrit's virtual branches (refs/for/*) in
 order to record a new review request. This means that one cannot stop
 the request from happening just by dying inside the hook. Instead,
@@ -931,6 +966,19 @@ compliance. Plugins that implement C<pre-commit>, C<commit-msg>,
 C<update>, or C<pre-receive> hooks usually also implement this Gerrit
 hook.
 
+Since draft patchsets are visible only by their owners, the
+B<patchset-created> hook is unusable because it uses a fixed user to
+authenticate. So, Git::Hooks exit prematurely when invoked as the
+B<patchset-created> hook for a draft change.
+
+=head3 draft-published
+
+The B<draft-published> hook is executed when the user publishes a draft
+change, making it visible to other users. Since the B<patchset-created> hook
+doesn't work for draft changes, the B<draft-published> hook is a good time
+to work on them. All plugins that work on the B<patchset-created> also work
+on the B<draft-published> hook to cast a vote when drafts are published.
+
 =head1 CONFIGURATION
 
 Git::Hooks is configured via Git's own configuration
@@ -1185,6 +1233,16 @@ STDERR but let the commit succeed. This way, the user can correct any
 mistake with a simple C<git commit --amend> and doesn't run the risk
 of losing the commit message.
 
+=head2 githooks.nocarp [01]
+
+By default all errors produced by Git::Hooks use L<Carp::croak>, so that
+they contain a suffix telling where the error occurred. Sometimes you may
+not want this. For instance, if you receive the error message produced by a
+server hook you won't be able to use that information.
+
+So, for server hooks you may want to set this configuration variable to 1 to
+strip those suffixes from the error messages.
+
 =head2 githooks.gerrit.url URL
 =head2 githooks.gerrit.username USERNAME
 =head2 githooks.gerrit.password PASSWORD
@@ -1193,23 +1251,33 @@ These three options are required if you enable Gerrit hooks. They are
 used to construct the C<Gerrit::REST> object that is used to interact
 with Gerrit.
 
-=head2 githooks.gerrit.review_label LABEL
+=head2 githooks.gerrit.review-label LABEL
 
 This option defines the
-L<label|http://gerrit-documentation.googlecode.com/svn/Documentation/2.6/config-labels.html>
-that must be used in Gerrit's review process. If not specified, the
-standard C<Code-Review> label is used.
+L<label|https://gerrit-review.googlesource.com/Documentation/config-labels.html>
+that must be used in Gerrit's review process. If not specified, the standard
+C<Code-Review> label is used.
 
-=head2 githooks.gerrit.vote_ok +N
+=head2 githooks.gerrit.vote-ok +N
 
 This option defines the vote that must be used to approve a review. If
 not specified, +1 is used.
 
-=head2 githooks.gerrit.vote_nok -N
+=head2 githooks.gerrit.vote-nok -N
 
 This option defines the vote that must be used to reject a review. If
 not specified, -1 is used.
 
+=head2 githooks.gerrit.comment-ok COMMENT
+
+By default, when approving a review Git::Hooks simply casts a positive vote
+but does not add any comment to the change. If you set this option, it adds
+a comment like this in addition to casting the vote:
+
+  [Git::Hooks] COMMENT
+
+You may want to use a simple comment like 'OK'.
+
 =head1 MAIN FUNCTION
 
 =head2 run_hook(NAME, ARGS...)
@@ -1254,7 +1322,7 @@ send notifications or to signal the completion of the action someway.
 
 You may learn about every Git hook by invoking the command C<git help
 hooks>. Gerrit hooks are documented in the L<project
-site|http://gerrit-documentation.googlecode.com/svn/Documentation/2.6/config-hooks.html>.
+site|https://gerrit-review.googlesource.com/Documentation/config-hooks.html>.
 
 Also note that each hook directive can be called more than once if you
 need to implement more than one specific hook.
@@ -1327,6 +1395,7 @@ hooks using the C<Git::Hooks::get_input_data> method.
 
 =item * REF_UPDATE(GIT, OPTS)
 =item * PATCHSET_CREATED(GIT, OPTS)
+=item * DRAFT_PUBLISHED(GIT, OPTS)
 
 These are Gerrit-specific hooks. Gerrit invokes them passing a list of
 option/value pairs which are converted into a hash, which is passed by
@@ -1456,6 +1525,10 @@ A thin wrapper around Gerrit's REST API.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/gnustavo/Git-Hooks>
+
 =head1 AUTHOR
 
 Gustavo L. de M. Chaves <gnustavo@cpan.org>
