@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckJira;
 {
-  $Git::Hooks::CheckJira::VERSION = '0.048';
+  $Git::Hooks::CheckJira::VERSION = '0.049';
 }
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages.
 
@@ -72,14 +72,14 @@ sub _jira {
         my %jira;
         for my $option (qw/jiraurl jirauser jirapass/) {
             $jira{$option} = $git->get_config($CFG => $option)
-                or $git->error($PKG, "Missing $CFG.$option configuration attribute.\n")
+                or $git->error($PKG, "Missing $CFG.$option configuration attribute")
                     and return;
         }
         $jira{jiraurl} =~ s:/+$::; # trim trailing slashes from the URL
 
         my $jira = eval { JIRA::REST->new($jira{jiraurl}, $jira{jirauser}, $jira{jirapass}) };
         length $@
-            and $git->error($PKG, "cannot connect to the JIRA server at '$jira{jiraurl}' as '$jira{jirauser}': $@\n")
+            and $git->error($PKG, "cannot connect to the JIRA server at '$jira{jiraurl}' as '$jira{jirauser}", $@)
                 and return;
         $cache->{jira} = $jira;
     }
@@ -100,21 +100,13 @@ sub get_issue {
     unless (exists $cache->{keys}{$key}) {
         $cache->{keys}{$key} = eval { $jira->GET("/issue/$key") };
         length $@
-            and $git->error($PKG, "cannot get issue $key: $@\n")
+            and $git->error($PKG, "cannot get issue $key", $@)
                 and return;
     }
 
     return $cache->{keys}{$key};
 }
 
-sub ferror {
-    my ($key, $commit, $ref, $error) = @_;
-    my $msg = "issue $key, $error.\n  (cited ";
-    $msg .= "by $commit->{commit} " if $commit->{commit};
-    $msg .= "in $ref)\n";
-    return $msg;
-}
-
 sub check_codes {
     my ($git) = @_;
 
@@ -127,22 +119,22 @@ sub check_codes {
             $code = do $check;
             unless ($code) {
                 if (length $@) {
-                    $git->error($PKG, "couldn't parse option check-code ($check): $@\n");
+                    $git->error($PKG, "couldn't parse option check-code ($check)", $@);
                 } elsif (! defined $code) {
-                    $git->error($PKG, "couldn't do option check-code ($check): $!\n");
+                    $git->error($PKG, "couldn't do option check-code ($check)", $!);
                 } else {
-                    $git->error($PKG, "couldn't run option check-code ($check)\n");
+                    $git->error($PKG, "couldn't run option check-code ($check)");
                 }
                 next CODE;
             }
         } else {
             $code = eval $check; ## no critic (BuiltinFunctions::ProhibitStringyEval)
             length $@
-                and $git->error($PKG, "couldn't parse option check-code value:\n$@\n")
+                and $git->error($PKG, "couldn't parse option check-code value", $@)
                     and next CODE;
         }
         is_code_ref($code)
-            or $git->error($PKG, "option check-code must end with a code ref.\n")
+            or $git->error($PKG, "option check-code must end with a code ref")
                 and next CODE;
         push @codes, $code;
     }
@@ -167,22 +159,21 @@ sub _check_jira_keys {
                 and next KEY;
 
         if ($unresolved && defined $issue->{fields}{resolution}) {
-            $git->error($PKG, ferror($key, $commit, $ref, "is already resolved"));
+            $git->error($PKG, "issue $key is already resolved");
             $errors++;
             next KEY;
         }
 
         if ($by_assignee) {
             my $user = $git->authenticated_user()
-                or $git->error($PKG, ferror($key, $commit, $ref, "cannot grok the authenticated user"))
+                or $git->error($PKG, "cannot grok the authenticated user")
                     and $errors++
                         and next KEY;
 
             my $assignee = $issue->{fields}{assignee}{name};
 
             $user eq $assignee
-                or $git->error($PKG, ferror($key, $commit, $ref,
-                                            "is currently assigned to '$assignee' but should be assigned to you ($user)"))
+                or $git->error($PKG, "issue $key should be assigned to '$user', not '$assignee'")
                     and $errors++
                         and next KEY;
         }
@@ -244,6 +235,8 @@ EOF
 sub check_patchset {
     my ($git, $opts) = @_;
 
+    _setup_config($git);
+
     my $sha1   = $opts->{'--commit'};
     my $commit = ($git->get_commits("$sha1^", $sha1))[-1];
 
@@ -317,6 +310,7 @@ UPDATE           \&check_affected_refs;
 PRE_RECEIVE      \&check_affected_refs;
 REF_UPDATE       \&check_affected_refs;
 PATCHSET_CREATED \&check_patchset;
+DRAFT_PUBLISHED  \&check_patchset;
 1;
 
 __END__
@@ -331,7 +325,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 DESCRIPTION
 
@@ -382,7 +376,7 @@ option:
 
     git config --add githooks.plugin CheckJira
 
-=for Pod::Coverage check_codes check_commit_msg check_ref ferror get_issue grok_msg_jiras
+=for Pod::Coverage check_codes check_commit_msg check_ref get_issue grok_msg_jiras
 
 =head1 NAME
 
