@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckLog;
 {
-  $Git::Hooks::CheckLog::VERSION = '0.048';
+  $Git::Hooks::CheckLog::VERSION = '0.049';
 }
 # ABSTRACT: Git::Hooks plugin to enforce commit log policies.
 
@@ -52,7 +52,7 @@ sub _spell_checker {
 
     unless (state $tried_to_check) {
         unless (eval { require Text::SpellChecker; }) {
-            $git->error($PKG, "Could not require Text::SpellChecker module to spell messages.\n$@\n");
+            $git->error($PKG, "Could not require Text::SpellChecker module to spell messages", $@);
             return;
         }
 
@@ -67,7 +67,7 @@ sub _spell_checker {
 
         my $word = eval { $checker->next_word(); };
         length $@
-            and $git->error($PKG, "Cannot spell check using Text::SpellChecker.\n$@\n")
+            and $git->error($PKG, "Cannot spell check using Text::SpellChecker", $@)
                 and return;
 
         $tried_to_check = 1;
@@ -90,15 +90,12 @@ sub check_spelling {
     my $errors = 0;
 
     foreach my $badword ($checker->next_word()) {
-        unless ($errors++) {
-            $git->error($PKG, "$id\'s log has the following spelling problems in it.\n");
-        }
         my @suggestions = $checker->suggestions($badword);
-        if (defined $suggestions[0]) {
-            $git->error($PKG, "  $badword (suggestions: ", join(', ', @suggestions), ")\n");
-        } else {
-            $git->error($PKG, "  $badword (no suggestions)\n");
-        }
+        $git->error(
+            $PKG,
+            "$id\'s log has a misspelled word: '$badword'",
+            defined $suggestions[0] ? "suggestions: " . join(', ', @suggestions) : undef,
+        );
     }
 
     return $errors == 0;
@@ -112,11 +109,11 @@ sub check_patterns {
     foreach my $match ($git->get_config($CFG => 'match')) {
         if ($match =~ s/^!\s*//) {
             $msg !~ /$match/m
-                or $git->error($PKG, "$id\'s log SHOULD NOT match \Q$match\E.\n")
+                or $git->error($PKG, "$id\'s log SHOULD NOT match '\Q$match\E'")
                     and $errors++;
         } else {
             $msg =~ /$match/m
-                or $git->error($PKG, "$id\'s log SHOULD match \Q$match\E.\n")
+                or $git->error($PKG, "$id\'s log SHOULD match '\Q$match\E'")
                     and $errors++;
         }
     }
@@ -131,11 +128,11 @@ sub check_title {
         or return 1;
 
     defined $title
-        or $git->error($PKG, "$id\'s log needs a title line!\n")
+        or $git->error($PKG, "$id\'s log needs a title line")
             and return 0;
 
     ($title =~ tr/\n/\n/) == 1
-        or $git->error($PKG, "$id\'s log title should have just one line!\n")
+        or $git->error($PKG, "$id\'s log title should have just one line")
             and return 0;
 
     my $errors = 0;
@@ -143,21 +140,21 @@ sub check_title {
     if (my $max_width = $git->get_config($CFG => 'title-max-width')) {
         my $tlen = length($title) - 1; # discount the newline
         $tlen <= $max_width
-            or $git->error($PKG, "$id\'s log title should be at most $max_width characters wide, but it has $tlen!\n")
+            or $git->error($PKG, "$id\'s log title should be at most $max_width characters wide, but it has $tlen")
                 and $errors++;
     }
 
     if (my $period = $git->get_config($CFG => 'title-period')) {
         if ($period eq 'deny') {
             $title !~ /\.$/
-                or $git->error($PKG, "$id\'s log title SHOULD NOT end in a period.\n")
+                or $git->error($PKG, "$id\'s log title SHOULD NOT end in a period")
                     and $errors++;
         } elsif ($period eq 'require') {
             $title =~ /\.$/
-                or $git->error($PKG, "$id\'s log title SHOULD end in a period.\n")
+                or $git->error($PKG, "$id\'s log title SHOULD end in a period")
                     and $errors++;
         } elsif ($period ne 'allow') {
-            $git->error($PKG, "Invalid value for the $CFG.title-period option: '$period'.\n")
+            $git->error($PKG, "Invalid value for the $CFG.title-period option: '$period'")
                 and $errors++;
         }
     }
@@ -174,7 +171,7 @@ sub check_body {
         if (my @biggies = ($body =~ /^(.{$max_width,})/gm)) {
             my $aremany = (@biggies == 1 ? "is " : "are ") . scalar(@biggies);
             $git->error($PKG, "$id\'s log body lines should be at most $max_width characters wide, "
-                            . "but there $aremany bigger than that in it!\n");
+                            . "but there $aremany bigger than that in it");
             return 0;
         }
     }
@@ -223,7 +220,7 @@ sub check_message_file {
     my $msg = eval {$git->read_commit_msg_file($commit_msg_file)};
 
     unless (defined $msg) {
-        $git->error($PKG, "Cannot read commit message file '$commit_msg_file': $@\n");
+        $git->error($PKG, "Cannot read commit message file '$commit_msg_file'", $@);
         return 0;
     }
 
@@ -267,6 +264,7 @@ UPDATE           \&check_affected_refs;
 PRE_RECEIVE      \&check_affected_refs;
 REF_UPDATE       \&check_affected_refs;
 PATCHSET_CREATED \&check_patchset;
+DRAFT_PUBLISHED  \&check_patchset;
 
 1;
 
@@ -282,7 +280,7 @@ Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies.
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 DESCRIPTION
 
