@@ -1,6 +1,6 @@
 package Git::More;
 {
-  $Git::More::VERSION = '0.048';
+  $Git::More::VERSION = '0.049';
 }
 # ABSTRACT: A Git extension with some goodies for hook developers.
 
@@ -432,10 +432,30 @@ sub get_current_branch {
 }
 
 sub error {
-    my ($git, $prefix, $message) = @_;
+    my ($git, $prefix, $message, $details) = @_;
+    $message =~ s/\n*$//s;    # strip trailing newlines
     my $fmtmsg = "\n[$prefix] $message";
-    push @{$git->{more}{errors}}, "$fmtmsg\n";
-    warn "$fmtmsg\n";
+    if ($details) {
+        # The details may have been generated by Carp::croak, in which case
+        # it will contain a suffix telling where the error
+        # occurred. Sometimes you may not want this. For instance, if the
+        # user is going to receive the error message produced by a server
+        # hook he/she won't be able to use that information. So, we may have
+        # to strip the context from the details.
+        $details =~ s/ at .*? line \d+(?: thread \d+)?\.?$//s
+            if $git->{more}{nocarp};
+
+        $details =~ s/\n*$//s; # strip trailing newlines
+        $details =~ s/^/  /gm; # prefix each line with two spaces
+        $fmtmsg .= ":\n\n$details\n";
+    }
+    $fmtmsg .= "\n";            # end in a newline
+    push @{$git->{more}{errors}}, $fmtmsg;
+    if ($git->{more}{nocarp}) {
+        warn $fmtmsg;           ## no critic (RequireCarping)
+    } else {
+        carp $fmtmsg;
+    }
     return 1;
 }
 
@@ -448,6 +468,12 @@ sub get_errors {
     }
 }
 
+sub nocarp {
+    my ($git) = @_;
+    $git->{more}{nocarp} = 1;
+    return;
+}
+
 
 1; # End of Git::More
 
@@ -463,7 +489,7 @@ Git::More - A Git extension with some goodies for hook developers.
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 SYNOPSIS
 
@@ -781,20 +807,43 @@ by the C<git symbolic-ref HEAD> command.
 If the repository is in a dettached head state, i.e., if HEAD points
 to a commit instead of to a branch, the method returns undef.
 
-=head2 error PREFIX MESSAGE
+=head2 error PREFIX MESSAGE [DETAILS]
 
-This method should be used by plugins to record consistent error or
-warning messages. It gets two arguments: a PREFIX and the error
-MESSAGE. The PREFIX is usually the plugin's package name.
+This method should be used by plugins to record consistent error or warning
+messages. It gets two or three arguments. The PREFIX is usually the plugin's
+package name. The MESSAGE is a oneline string. These two arguments are
+combined to produce a single line like this:
 
-The method simply records the error message and returns. It doesn't
-die.
+  [PREFIX] MESSAGE
+
+DETAILS is an optional string. If present, it is appended to the line above,
+separated by an empty line, and with its lines prefixed by two spaces, like
+this:
+
+  [PREFIX] MESSAGE
+
+    DETAILS
+    MORE DETAILS...
+
+The method simply records the formatted error message and returns. It
+doesn't die.
 
 =head2 get_errors
 
 This method returns a list of all error messages recorded with the
 C<error> method.
 
+=head2 nocarp
+
+By default all errors produced by Git::Hooks use L<Carp::croak>, so that
+they contain a suffix telling where the error occurred. Sometimes you may
+not want this. For instance, if the user is going to receive the error
+message produced by a server hook he/she won't be able to use that
+information.
+
+This method makes B<error> strip any such suffixes from its DETAILS argument
+and to produce its own message with B<warn> instead of B<carp>.
+
 =head1 SEE ALSO
 
 C<Git>
